ElfSegmentType enum
An enum containing segment types
Values
- none → const ElfSegmentType
-
const ElfSegmentType(0x0, null, 'PT_NULL', '') - load → const ElfSegmentType
-
const ElfSegmentType(0x1, null, 'PT_LOAD', '') - dynamic → const ElfSegmentType
-
const ElfSegmentType(0x2, null, 'PT_DYNAMIC', '') - interp → const ElfSegmentType
-
const ElfSegmentType(0x3, null, 'PT_INTERP', '') - note → const ElfSegmentType
-
const ElfSegmentType(0x4, null, 'PT_NOTE', '') - shlib → const ElfSegmentType
-
const ElfSegmentType(0x5, null, 'PT_SHLIB', '') - phdr → const ElfSegmentType
-
const ElfSegmentType(0x6, null, 'PT_PHDR', '') - tls → const ElfSegmentType
-
const ElfSegmentType(0x7, null, 'PT_TLS', '') - num → const ElfSegmentType
-
const ElfSegmentType(0x8, null, 'PT_NUM', 'Number of defined types') - gnuEhFrame → const ElfSegmentType
-
const ElfSegmentType(0x6474e550, null, 'PT_GNU_EH_FRAME', 'GCC .eh_frame_hdr segment') - gnuStack → const ElfSegmentType
-
const ElfSegmentType(0x6474e551, null, 'PT_GNU_STACK', 'Indicates stack execution') - gnuRelRO → const ElfSegmentType
-
const ElfSegmentType(0x6474e552, null, 'PT_GNU_RELRO', 'Read-only after relocation') - gnuProperty → const ElfSegmentType
-
const ElfSegmentType(0x6474e553, null, 'PT_GNU_PROPERTY', 'GNU property') - sunSegment → const ElfSegmentType
-
const ElfSegmentType(0x6ffffffa, null, 'PT_SUNWBSS', 'Sun specific segment') - sunStack → const ElfSegmentType
-
const ElfSegmentType(0x6ffffffb, null, 'PT_SUNWSTACK', 'Sun stack segment') - os → const ElfSegmentType
-
const ElfSegmentType(0x60000000, null, 'PT_LOOS', 'OS specific') - processor → const ElfSegmentType
-
const ElfSegmentType(0x70000000, null, 'PT_LOPROC', 'Processor specific') - mipsRegisterUsageInfo → const ElfSegmentType
-
const ElfSegmentType(0x70000000, ElfArchitectureIdentifier.mips, 'PT_MIPS_REGINFO', 'MIPS register usage') - mipsRuntimeProcedureTable → const ElfSegmentType
-
const ElfSegmentType(0x70000001, ElfArchitectureIdentifier.mips, 'PT_MIPS_RTPROC', 'MIPS runtime procedure table') - mipsOptions → const ElfSegmentType
-
const ElfSegmentType(0x70000002, ElfArchitectureIdentifier.mips, 'PT_MIPS_OPTIONS', 'MIPS .MIPS.options section') - armExIdx → const ElfSegmentType
-
const ElfSegmentType(0x70000001, ElfArchitectureIdentifier.arm, 'PT_ARM_EXIDX', 'ARM EXIDX')
Properties
- arch → ElfArchitectureIdentifier?
-
final
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
byArchitecture(
ElfArchitectureIdentifier arch, int id) → ElfSegmentType -
Finds a segment type given an
archand anid. -
byId(
int id) → ElfSegmentType -
Finds a segment type given an
id.
Constants
-
values
→ const List<
ElfSegmentType> - A constant List of the values in this enum, in order of their declaration.